/*
В качестве примера скопируйте файл «Arduino.raw» 
входящим в состав библиотеки «UTFT_SdRaw» на SD-карту
*/

#include <SPI.h>
// расширенная библиотека для работы с SD-картой
#include <SdFat.h>
// библиотека для работы с дисплеем
#include <UTFT.h>
// библиотека для вывода изображений на дисплеей с SD-карты
#include <UTFT_SdRaw.h>

// пин ChipSelect к которому подключена SD-карта
#define SD_CHIP_SELECT  53

// создаём объект работы с SD-картой
SdFat sd;

// создаём объект класса UTFT
// и передаём идентификатор модели дисплея и номера управляющих пинов
UTFT myGLCD(CTE32HR, 38, 39, 40, 41);

// объявления встроенного шрифта
extern uint8_t BigFont[];

// создаём объект для работы и вывода изображений на дисплей
UTFT_SdRaw myFiles(&myGLCD);

void setup()
{
  // инициализируем дисплей с вертикальной ориентацией
  myGLCD.InitLCD();
  // очищаем экран
  myGLCD.clrScr();
  // выбираем большой шрифт
  myGLCD.setFont(BigFont);

  // ждём успешной инициализации SD-карты
  while (!sd.begin(SD_CHIP_SELECT)) {
    // устанавливаем красный цвет «чернил» для печати и рисования
    myGLCD.setColor(VGA_RED);
    // печатаем строку в указанной строке позиции
    myGLCD.print("SD Card failed!", CENTER, 100);
    delay(1000);
  }

  // устанавливаем зелённый цвет «чернил» для печати и рисования
  myGLCD.setColor(VGA_GREEN);
  // печатаем строку в указанной строке позиции
  myGLCD.print("SD Card initialised", CENTER, 100);
  // ждём 1 секунду
  delay(1000);

  // выводим изображение с SD-карты на дисплей
  myFiles.load(0, 0, 480, 320, "Arduino.RAW");
}

void loop()
{
}
